# mileva

_Python toolkit for symbolic computations in General Relativity._

![Build status](https://github.com/Poincare-code/mileva/actions/workflows/build-and-test.yaml/badge.svg)
![Build status](https://github.com/Poincare-code/mileva/actions/workflows/upload-to-pypi.yaml/badge.svg)
![Build status](https://github.com/Poincare-code/mileva/actions/workflows/upload-to-anaconda.yaml/badge.svg)


## About

Mostly just sympy wrappers, tailored to my personal needs.


## Installation

Get the latest release (version 0.0.2) either from [PyPI](https://pypi.org/project/pomme/), using `pip`, with:
```
pip install mileva
```
or from [Anaconda.org](https://anaconda.org/FredDeCeuster/pomme) (only linux-64 and osx-intel-64), using `conda`, with:
```
conda install -c freddeceuster mileva
```
or download the [source code](https://github.com/Magritte-code/pomme/archive/refs/heads/main.zip), unzip, and install with `pip` by executing:
```
pip install .
```
in the root directory of the code.